@@ -19,39 +19,43 @@ from simeon.download.utilities import decrypt_files
 
 BUCKETS = {
     'email': {
-        'Bucket': 'course-data',
+        'Bucket': '{bucket}',
         'Prefix': 'email-opt-in/email-opt-in-{org}-',
     },
     'sql': {
-        'Bucket': 'course-data',
+        'Bucket': '{bucket}',
         'Prefix': '{org}-',
     },
     'log': {
-        'Bucket': 'edx-course-data',
+        'Bucket': '{bucket}',
         'Prefix': '{org}/{site}/events/{year}/{org}-{site}-events-',
     },
     'rdx': {
-        'Bucket': 'edx-course-data',
+        'Bucket': '{bucket}',
         'Prefix': '{org}/rdx/{request}',
     },
 }
 BEGIN_DATE = '2012-09-01'
-END_DATE = datetime.today().strftime('%Y-%m-%d')
+END_DATE = datetime.utcnow().strftime('%Y-%m-%d')
 DATE_PATT = re.compile(r'\d{4}-\d{2}-\d{2}')
 O2B_MAP = dict(
     key='name', last_modified='last_modified', size='size'
 )
 
 
-def make_s3_bucket(bucket, client_id=None, client_secret=None):
+def make_s3_bucket(
+    bucket, client_id=None, client_secret=None, session_token=None,
+    profile_name=None,
+):
     """
     Make a simple boto3 Bucket object pointing to S3
     """
     try:
-        resource = boto.resource(
-            's3', aws_access_key_id=client_id,
-            aws_secret_access_key=client_secret
+        session = boto.Session(
+            aws_access_key_id=client_id, aws_secret_access_key=client_secret,
+            aws_session_token=session_token, profile_name=profile_name,
         )
+        resource = session.resource('s3')
         return resource.Bucket(bucket)
     except Exception as excp:
         raise AWSException(excp)
