@@ -119,9 +119,13 @@ def decrypt_files(
                     logger.warning(msg.format(f=file_, e=excp))
     if verbose:
         msgs = []
-        for line in proc.stdout:
-            msgs.append(line.decode('utf8', 'ignore').strip())
-        if msgs:
+        # If stderr is needed, then add it to the tuple below
+        for stream in (proc.stdout,):
+            for line in stream:
+                line = line.decode('utf8', 'ignore').strip()
+                if line:
+                    msgs.append(line)
+        if msgs and logger:
             logger.warning('\n'.join(msgs))
     return True
 
@@ -150,7 +154,7 @@ def make_file_handle(fname: str, mode: str='wt', is_gzip: bool=False):
     :type fname: str
     :param fname: A file name whose handle needs to be created.
     :type mode: str
-    :param mode: "a[b]?" for append or "w[b]?" for write
+    :param mode: "a[bt]?" for append or "w[bt]?" for write
     :type is_gzip: bool
     :param is_gzip: Whether or not to open it as a gzip file handle
     :rtype: Union[TextIOWrapper, BufferedReader]
