@@ -152,6 +152,19 @@ PROBLEM_TYPES = {
     'multiplechoiceresponse', 'numericalresponse',
     'optionresponse', 'stringresponse', 'schematicresponse',
 }
+# These are the file names used to make .json.gz files for tables
+# such as user_info_combo, course_axis, etc.
+TARGET_FILES = (
+    'auth_user-analytics.sql', 'auth_userprofile-analytics.sql',
+    'certificates_generatedcertificate-analytics.sql',
+    'course-analytics.xml.tar.gz', 'course_structure-analytics.json',
+    'courseware_studentmodule-analytics.sql',
+    'django_comment_client_role_users-analytics.sql', 'forum.mongo',
+    'grades_persistentcoursegrade-analytics.sql',
+    'grades_persistentsubsectiongrade-analytics.sql',
+    'student_courseaccessrole-analytics.sql',
+    'student_courseenrollment-analytics.sql', 'user_id_map-analytics.sql'
+)
 
 
 def _sql_pool_init():
@@ -187,6 +200,31 @@ def _report_pool_init(proj, safile=None):
         )
 
 
+def _course_has_all_files(folder, files=TARGET_FILES, encrypted=False):
+    """
+    Checks that a target course has all the required files to make
+    tables like user_info_combo, course_axis, etc.
+    These tables are the ones generated by the split command when file type
+    is sql.
+
+    :type folder: str
+    :param folder: A given course's folder from unpacking the SQL archive
+    :type files: Tuple[str]
+    :param files: A tuple of base file names
+    :type encrypted: bool
+    :param encrypted: Whether the files have additional .gpg for extension
+    :rtype: bool
+    :return: True if all files are available, False otherwise.
+    """
+    fs = []
+    for f in files:
+        if encrypted and not f.endswith('.gpg'):
+            f = f + '.gpg'
+        fs.append(f)
+    fs = map(lambda f: os.path.join(folder, os.path.basename(f)), fs)
+    return all(map(os.path.exists, fs))
+
+
 def _get_schema_dict(sdir, table):
     """
     Find a matching JSON schema file in the directory sdir
@@ -1401,7 +1439,7 @@ def make_table_from_sql(
                 geo_table=geo_table, youtube_table=youtube_table,
                 course_id=course_id, **kwargs
             ),
-            job_id_prefix='{t}_{dt}'.format(
+            job_id_prefix='simeon_query_{t}_{dt}'.format(
                 t=table.replace('.', '_'),
                 dt=datetime.now().strftime('%Y%m%d%H%M%S%f')
             ),
@@ -1468,12 +1506,15 @@ def make_tables_from_sql(
     dataset.description = gcp.DST_DESC.get('sql', '')
     client.create_dataset(dataset, exists_ok=True)
     for table in tables:
-        out[table] = make_table_from_sql(
-            table=table, course_id=course_id, client=client, project=project,
-            append=append, geo_table=geo_table, wait=wait,
-            query_dir=query_dir, youtube_table=youtube_table,
-            schema_dir=schema_dir, **kwargs
-        )
+        try:
+            out[table] = make_table_from_sql(
+                table=table, course_id=course_id, client=client,
+                project=project, append=append, geo_table=geo_table,
+                wait=wait, query_dir=query_dir, youtube_table=youtube_table,
+                schema_dir=schema_dir, **kwargs
+            )
+        except Exception as excp:
+            out[table] = [{'message': str(excp)}]
         # If fail_fast is requested, and making the table
         # returns a dictionary of errors, then return
         if fail_fast and out[table]:
