@@ -1,12 +1,17 @@
 """
 Utility functions for the simeon CLI tool
 """
+import argparse
+import configparser
 import glob
 import logging
 import os
+import shlex
 import socket
+import stat
+import subprocess as sb
 import sys
-import configparser
+import tempfile
 from argparse import ArgumentTypeError
 
 from dateutil.parser import parse as dateparse
@@ -215,6 +220,10 @@ CONFIGS = {
         ('geo_table', configparser.ConfigParser.get),
         ('youtube_table', configparser.ConfigParser.get),
         ('extra_args', configparser.ConfigParser.get),
+        ('email_bucket', configparser.ConfigParser.get),
+        ('sql_bucket', configparser.ConfigParser.get),
+        ('log_bucket', configparser.ConfigParser.get),
+        ('rdx_bucket', configparser.ConfigParser.get),
     ),
     'GCP': (
         ('project', configparser.ConfigParser.get),
@@ -234,6 +243,10 @@ CONFIGS = {
     'AWS': (
         ('aws_cred_file', configparser.ConfigParser.get),
         ('profile_name', configparser.ConfigParser.get),
+        ('email_bucket', configparser.ConfigParser.get),
+        ('sql_bucket', configparser.ConfigParser.get),
+        ('log_bucket', configparser.ConfigParser.get),
+        ('rdx_bucket', configparser.ConfigParser.get),
     ),
 }
 REPORT_TABLES = [
@@ -245,7 +258,8 @@ REPORT_TABLES = [
     'pc_day_ip_counts', 'language_multi_transcripts', 'pc_nchapters',
     'pc_forum', 'course_modal_language', 'course_modal_ip',
     'forum_posts', 'forum_person', 'enrollment_events', 'enrollday_all',
-    'person_enrollment_verified', 'person_course',
+    'person_enrollment_verified', 'pc_day_agent_counts', 'course_modal_agent',
+    'person_course',
 ]
 EXTRA_ARG_TYPE = {'i': int, 'f': float, 's': str,}
 
@@ -338,15 +352,11 @@ def make_logger(user='SIMEON', verbose=True, stream=None):
         '%(asctime)s:%(hostname)s:%(levelname)s:%(name)s:%(message)s',
         '%Y-%m-%d %H:%M:%S%z'
     )
-    # formatter = logging.Formatter(
-    #     '%(asctime)s:%(levelname)s:%(name)s:%(message)s',
-    #     '%Y-%m-%d %H:%M:%S%z'
-    # )
+    logger = logging.getLogger(user)
     handler = logging.StreamHandler(stream=stream)
     handler.setLevel(level)
     handler.set_name(user)
     handler.setFormatter(formatter)
-    logger = logging.Logger(user, level)
     logger.addHandler(handler)
     return logging.LoggerAdapter(logger, {'hostname': socket.gethostname()})
 
@@ -619,10 +629,78 @@ class NumberRange(object):
         return v
 
 
+class TableOrderAction(argparse.Action):
+    def __call__(self, parser, namespace, values, option_string):
+        if any(k in sys.argv for k in ('--no-reorder', '-O')):
+            print(values)
+            setattr(namespace, 'tables', values)
+            return
+        tables = []
+        for table in REPORT_TABLES:
+            if table in values:
+                tables.append(table)
+        if not tables:
+            if not values:
+                raise ArgumentTypeError(
+                    'Table names required when --tables is given'
+                )
+            setattr(namespace, 'tables', values)
+            return
+        for table in values:
+            if table not in tables:
+                tables.append(table)
+        setattr(namespace, 'tables', tables)
+
+
+def get_pager():
+    """
+    Get path to less or more
+    """
+    pagers = (os.getenv('PAGER'), 'less', 'more',)
+    for path in (os.getenv('PATH') or '').split(os.path.pathsep):
+        for pager in pagers:
+            if pager is None:
+                continue
+            pager = iter(pager.split(' ', 1))
+            prog = os.path.join(path, next(pager))
+            args = next(pager, None) or ''
+            try:
+                md = os.stat(prog).st_mode
+                if md & (stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH):
+                    return '{p} {a}'.format(p=prog, a=args)
+            except OSError:
+                continue
+
+
+class CustomArgParser(argparse.ArgumentParser):
+    """
+    A custom ArgumentParser class that prints help messages
+    using either less or more, if available. Otherwise, it does
+    what ArgumentParser does.
+    """
+    def print_help(self, file=None):
+        text = self.format_help()
+        pager = get_pager()
+        if pager is None:
+            return super().print_help(file)
+        fd, fname = tempfile.mkstemp(prefix='simeon_help_', suffix='.txt')
+        with open(fd, 'w') as fh:
+            super().print_help(fh)
+        cmd = shlex.split('{p} {f}'.format(p=pager, f=fname))
+        with sb.Popen(cmd) as proc:
+            rc = proc.wait()
+            try:
+                os.unlink(fname)
+            except:
+                pass
+            if rc != 0:
+                return super().print_help(file)
+
+
 __all__ = [
-    'NumberRange', 'bq_table', 'course_listings', 'course_paths_from_file',
-    'courses_from_file', 'expand_paths', 'filter_generated_items',
-    'find_config', 'gcs_bucket', 'is_parallel', 'items_from_files',
-    'make_config_file', 'make_logger', 'optional_file',
-    'parsed_date', 'process_extra_args',
-]
\ No newline at end of file
+    'CustomArgParser', 'NumberRange', 'TableOrderAction', 'bq_table',
+    'course_listings', 'course_paths_from_file', 'courses_from_file',
+    'expand_paths', 'filter_generated_items', 'find_config', 'gcs_bucket',
+    'get_pager', 'is_parallel', 'items_from_files', 'make_config_file',
+    'make_logger', 'optional_file', 'parsed_date', 'process_extra_args',
+]
